[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --distributed-is-the-new-centralized
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/git-cvsexportcommit#_name)
    * [SYNOPSIS](https://git-scm.com/docs/git-cvsexportcommit#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/git-cvsexportcommit#_description)
    * [OPTIONS](https://git-scm.com/docs/git-cvsexportcommit#_options)
    * [CONFIGURATION](https://git-scm.com/docs/git-cvsexportcommit#_configuration)
    * [EXAMPLES](https://git-scm.com/docs/git-cvsexportcommit#_examples)
    * [GIT](https://git-scm.com/docs/git-cvsexportcommit#_git)


[ English ▾](https://git-scm.com/docs/git-cvsexportcommit)
Localized versions of **git-cvsexportcommit** manual
  1. [English ](https://git-scm.com/docs/git-cvsexportcommit)
  2. [Français ](https://git-scm.com/docs/git-cvsexportcommit/fr)
  3. [Português (Brasil) ](https://git-scm.com/docs/git-cvsexportcommit/pt_BR)
  4. [українська мова ](https://git-scm.com/docs/git-cvsexportcommit/uk)
  5. [简体中文 ](https://git-scm.com/docs/git-cvsexportcommit/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git-cvsexportcommit)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/git-cvsexportcommit) git-cvsexportcommit last updated in 2.35.0
Changes in the **git-cvsexportcommit** manual
  1. 2.35.1 → 2.53.0 no changes
  2. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git-cvsexportcommit/2.35.0)
  3. 2.1.4 → 2.34.8 no changes
  4. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-cvsexportcommit/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git-cvsexportcommit#_name)NAME
git-cvsexportcommit - Export a single commit to a CVS checkout
##  [](https://git-scm.com/docs/git-cvsexportcommit#_synopsis)SYNOPSIS
```
_git cvsexportcommit_ [-h] [-u] [-v] [-c] [-P] [-p] [-a] [-d <cvsroot>]
	[-w <cvs-workdir>] [-W] [-f] [-m <msgprefix>] [<parent-commit>] <commit-id>
```

##  [](https://git-scm.com/docs/git-cvsexportcommit#_description)DESCRIPTION
Exports a commit from Git to a CVS checkout, making it easier to merge patches from a Git repository into a CVS repository.
Specify the name of a CVS checkout using the -w switch or execute it from the root of the CVS working copy. In the latter case GIT_DIR must be defined. See examples below.
It does its best to do the safe thing, it will check that the files are unchanged and up to date in the CVS checkout, and it will not autocommit by default.
Supports file additions, removals, and commits that affect binary files.
If the commit is a merge commit, you must tell _git cvsexportcommit_ what parent the changeset should be done against.
##  [](https://git-scm.com/docs/git-cvsexportcommit#_options)OPTIONS

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--c)-c

Commit automatically if the patch applied cleanly. It will not commit if any hunks fail to apply or there were other problems.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--p)-p

Be pedantic (paranoid) when applying patches. Invokes patch with --fuzz=0

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--a)-a

Add authorship information. Adds Author line, and Committer (if different from Author) to the message.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--d)-d

Set an alternative CVSROOT to use. This corresponds to the CVS -d parameter. Usually users will not want to set this, except if using CVS in an asymmetric fashion.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--f)-f

Force the merge even if the files are not up to date.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--P)-P

Force the parent commit, even if it is not a direct parent.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--m)-m

Prepend the commit message with the provided prefix. Useful for patch series and the like.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--u)-u

Update affected files from CVS repository before attempting export.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--k)-k

Reverse CVS keyword expansion (e.g. $Revision: 1.2.3.4$ becomes $Revision$) in working CVS checkout before applying patch.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--w)-w

Specify the location of the CVS checkout to use for the export. This option does not require GIT_DIR to be set before execution if the current directory is within a Git repository. The default is the value of _cvsexportcommit.cvsdir_.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--W)-W

Tell cvsexportcommit that the current working directory is not only a Git checkout, but also the CVS checkout. Therefore, Git will reset the working directory to the parent commit before proceeding.

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt--v)-v

Verbose.
##  [](https://git-scm.com/docs/git-cvsexportcommit#_configuration)CONFIGURATION

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt-cvsexportcommitcvsdir)cvsexportcommit.cvsdir

The default location of the CVS checkout to use for the export.
##  [](https://git-scm.com/docs/git-cvsexportcommit#_examples)EXAMPLES

[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt-MergeonepatchintoCVS)Merge one patch into CVS

```
$ export GIT_DIR=~/project/.git
$ cd ~/project_cvs_checkout
$ git cvsexportcommit -v <commit-sha1>
$ cvs commit -F .msg <files>
```


[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt-MergeonepatchintoCVS-cand-woptionsTheworkingdirectoryiswithintheGitRepo)Merge one patch into CVS (-c and -w options). The working directory is within the Git Repo

```
	$ git cvsexportcommit -v -c -w ~/project_cvs_checkout <commit-sha1>
```


[](https://git-scm.com/docs/git-cvsexportcommit#Documentation/git-cvsexportcommit.txt-MergependingpatchesintoCVSautomaticallyonlyifyoureallyknowwhatyouaredoing)Merge pending patches into CVS automatically — only if you really know what you are doing

```
$ export GIT_DIR=~/project/.git
$ cd ~/project_cvs_checkout
$ git cherry cvshead myhead | sed -n 's/^+ //p' | xargs -l1 git cvsexportcommit -c -p -v
```

##  [](https://git-scm.com/docs/git-cvsexportcommit#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### cvsexportcommit
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
